@@ -10,6 +10,7 @@
 #' @importFrom stats pchisq
 #' @importFrom survMisc ten comp
 #' @importFrom utils capture.output
+#' @importFrom rlang !! sym
 
 
 # Count the number of ggplots in a list
@@ -55,7 +56,7 @@ GeomConfint <- ggplot2::ggproto('GeomConfint', ggplot2::GeomRibbon,
                                   if (na.rm) data <- data[stats::complete.cases(self$required_aes), ]
                                   data <- data[order(data$group, data$x), ]
                                   data <- self$stairstep_confint(data)
-                                  ggplot2:::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = FALSE)
+                                  ggplot2:::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = na.rm)
                                 },
                                 stairstep_confint = function (data) {
                                   data <- as.data.frame(data)[order(data$x), ]
@@ -103,15 +104,21 @@ GeomConfint_old <- ggplot2::ggproto('GeomConfint_old', ggplot2::GeomRibbon,
 .trim <- function(x){gsub("^\\s+|\\s+$", "", x)}
 
 # Take a data frame and return a flatten value
-.flat <- function(x){
-  if(is.null(x)) return(NA)
+# Replacement of deprecated tidyr::gather_() by pivot_longer()
+# Use col_vary = "slowest" to keep the same behavior as gather_()
+.flat <- function(x) {
+  if (is.null(x)) return(NA)
   x <- as.data.frame(x)
-  x <- tidyr::gather_(x,
-                      key_col = "key", value_col = "value",
-                      gather_cols = colnames(x))
+  x <- tidyr::pivot_longer(x,
+                           cols = colnames(x), 
+                           names_to = "key",
+                           values_to = "value",
+                           cols_vary = "slowest")
+
   x$value
 }
 
+
 # extract dataset if not provided
 .get_data <- function(fit, data = NULL, complain = TRUE) {
   if(is.null(data)){
@@ -239,7 +246,7 @@ GeomConfint_old <- ggplot2::ggproto('GeomConfint_old', ggplot2::GeomRibbon,
 # This is used for tables under the main survival plots
 #
 .set_large_dash_as_ytext <- function(ggp){
-  ggp + theme(axis.text.y = element_text(size = 50, vjust = 0.35),
+  ggp + theme(axis.text.y = ggtext::element_markdown(size = 50, vjust = 0.5),
         axis.ticks.y = element_blank())
 }
 
@@ -395,7 +402,7 @@ GeomConfint_old <- ggplot2::ggproto('GeomConfint_old', ggplot2::GeomRibbon,
 #       - data.formula: data off all variables in the formula including time and status
 .extract.survfit <- function(fit, data = NULL){
 
-  if(inherits(fit, "survfit.cox"))
+  if(inherits(fit, c("survfit.cox", "survfitcox")))
     return(list())
 
   .formula <- fit$call$formula %>%
